==> kadu_0.11.0.orig.tar.bz2: kadu-0.11.0/plugins/docking/translations/docking_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Oznamovací oblast panelu</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Start docked</source>
        <translation>Spustit ukotvení v panelu</translation>
    </message>
    <message>
        <source>Show tooltip in tray</source>
        <translation>Ukázat v oznamovací oblasti panelu radu k nástroji</translation>
    </message>
    <message>
        <source>New message tray icon</source>
        <translation>Ikona v oznamovací oblast panelu pro novou zprávu</translation>
    </message>
    <message>
        <source>Blinking envelope</source>
        <translation>Blikající obálka</translation>
    </message>
    <message>
        <source>Static envelope</source>
        <translation>Statická obálka</translation>
    </message>
    <message>
        <source>Animated envelope</source>
        <translation>Kreslená obálka</translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>Current status:
%1</source>
        <translation>Současný stav:
%1</translation>
    </message>
    <message>
        <source>

Description:
%2</source>
        <translation>

Popis:
%2</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Ukončit Kadu</translation>
    </message>
</context>
</TS>

==> kadu_0.12.0.orig.tar.bz2: kadu-0.12.0/plugins/docking/translations/docking_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Oznamovací oblast panelu</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Start docked</source>
        <translation>Spustit ukotvení v panelu</translation>
    </message>
    <message>
        <source>Show tooltip in tray</source>
        <translation>Ukázat v oznamovací oblasti panelu radu k nástroji</translation>
    </message>
    <message>
        <source>New chat tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>Current status:
%1</source>
        <translation>Současný stav:
%1</translation>
    </message>
    <message>
        <source>

Description:
%2</source>
        <translation>

Popis:
%2</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Ukončit Kadu</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
